@@ -6,7 +6,6 @@ import json
 import logging
 import os
 import random
-import shlex
 import socket
 import subprocess
 import sys
@@ -89,7 +88,6 @@ def create_runner(channel):
 
         data = json.loads(str(msg.body))
         cmd = data.get('cmd')
-        args = shlex.split(str(cmd))
         print 'starting'
         publish_result({
             'job_id': data.get('job_id'),
@@ -97,10 +95,9 @@ def create_runner(channel):
             'start_time': str(datetime.datetime.utcnow()),
             'type': 'starting',
         })
-        print args
         start = time.time()
         try:
-            proc = subprocess.Popen(args)
+            proc = subprocess.Popen(cmd, shell=True)
         except OSError as exc:
             print 'Failed', exc
             end = time.time()
